## Explanation of the Killstats Functionality

### General Call via the Sidemenu

When you normally call Killstats via the sidemenu, all corporations of the user are included in the filtering and displayed. For example:

- **Corporation A** - Character A (main character) lost an Ishtar 220m
- **Corporation B** - Character B (belongs to main character) lost a Vexor 100m
- **Corporation B** - Character C lost a Venture 5m
- **Corporation C as stranger** - Character D lost a Stabber 40m

In principle, sorting is always done alphabetically and by ISK.
In the Hall of Fame, a character can only appear once.

### Display in Hall of Shame

When the page is called, the following is displayed in the Hall of Shame:

#### Hall of Fame:

- **Character A** - Ishtar - 220m
- **Character B (Character A)** - 100m
- **Character C** - 5m

This means that characters who are also in other corporations are always displayed. The characters are always assigned to the main character. This applies to all content.

### Single View in Overview

The Overview only display Corporation/Alliances you are in.
However, if you go to the Overview and click on a corporation, a single view is displayed. This means that only the kills of the selected corporation are displayed and not summarized.

### Single View Corporation A:

#### Hall of Fame:

- **Character A** - Ishtar - 220m

### Single View Corporation B:

#### Hall of Fame:

- **Character B (Main Character)** - Vexor - 100m
- **Character C** - Venture - 5m

### Single View Corporation C:

#### Hall of Fame:

- **Character D** - Stabber - 40m
